[rkward-cvs] SF.net SVN: rkward-code:[4672] trunk/rkward/packages/rkwarddev

m-eik at users.sf.net m-eik at users.sf.net
Thu Apr 4 19:47:51 UTC 2013


Revision: 4672
          http://sourceforge.net/p/rkward/code/4672
Author:   m-eik
Date:     2013-04-04 19:47:50 +0000 (Thu, 04 Apr 2013)
Log Message:
-----------
rkwarddev: fixing the erroneous inclusion of pluginmaps in plugin XML files

Modified Paths:
--------------
    trunk/rkward/packages/rkwarddev/ChangeLog
    trunk/rkward/packages/rkwarddev/DESCRIPTION
    trunk/rkward/packages/rkwarddev/R/rk.XML.plugin.R
    trunk/rkward/packages/rkwarddev/R/rk.plugin.component.R
    trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R
    trunk/rkward/packages/rkwarddev/R/rkwarddev-package.R
    trunk/rkward/packages/rkwarddev/inst/NEWS.Rd
    trunk/rkward/packages/rkwarddev/inst/doc/rkwarddev_vignette.pdf
    trunk/rkward/packages/rkwarddev/man/rk.XML.plugin.Rd
    trunk/rkward/packages/rkwarddev/man/rk.plugin.component.Rd
    trunk/rkward/packages/rkwarddev/man/rkwarddev-package.Rd

Modified: trunk/rkward/packages/rkwarddev/ChangeLog
===================================================================
--- trunk/rkward/packages/rkwarddev/ChangeLog	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/ChangeLog	2013-04-04 19:47:50 UTC (rev 4672)
@@ -1,6 +1,6 @@
 ChangeLog for package rkwarddev
 
-changes in version 0.06-2 (2013-03-13)
+changes in version 0.06-2 (2013-04-04)
 changed:
   - the structure of <about> nodes will change in RKWard 0.6.1,
     <dependencies> will become a direct child of <document> or <component>, which explains
@@ -10,6 +10,9 @@
   - rk.XML.pluginmap(), rk.XML.plugin() and rk.plugin.skeleton() will now
     move <dependencies> from <about> to a top level child node of plugin maps,
     with a warning
+  - from rk.plugin.component() and rk.XML.plugin(), the "pluginmap" argument
+    was replaced by the more general "include", which can now also process a
+    vector of file names
   - the object class rk.JS.var gained a new slot "getter" to set a default JS
     function to query variable values. it defaults to "getValue" to ensure
     compatibility with earlier releases. consequently, rk.JS.vars() and
@@ -46,6 +49,7 @@
     rk.JS.scan() dealt with <frame> nodes, which was also fixed
   - fixed a duplicate entry in this ChangeLog for version 0.04-6
   - rk.plugin.skeleton() now correctly works with more than one author
+  - pluginmap files are no longer included into plugin XML files automatically
 
 changes in version 0.06-1 (2012-11-08)
 changed:

Modified: trunk/rkward/packages/rkwarddev/DESCRIPTION
===================================================================
--- trunk/rkward/packages/rkwarddev/DESCRIPTION	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/DESCRIPTION	2013-04-04 19:47:50 UTC (rev 4672)
@@ -15,7 +15,7 @@
 Authors at R: c(person(given="Meik", family="Michalke",
     email="meik.michalke at hhu.de", role=c("aut", "cre")))
 Version: 0.06-2
-Date: 2013-03-13
+Date: 2013-04-04
 Collate:
     'echo.R'
     'id.R'

Modified: trunk/rkward/packages/rkwarddev/R/rk.XML.plugin.R
===================================================================
--- trunk/rkward/packages/rkwarddev/R/rk.XML.plugin.R	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/R/rk.XML.plugin.R	2013-04-04 19:47:50 UTC (rev 4672)
@@ -14,7 +14,7 @@
 #'		sections the document should provide even if \code{dialog}, \code{wizard} and \code{logic} are \code{NULL}.
 #'		These sections must be edited manually and some parts are therefore commented out.
 #' @param help Logical, if \code{TRUE} an include tag for a help file named \emph{"<name>.rkh"} will be added to the header.
-#' @param pluginmap Character string, relative path to the pluginmap file, which will then be included in the head of this document.
+#' @param include Character string or vector, relative path(s) to other file(s), which will then be included in the head of the GUI XML document.
 #' @param label Character string, a text label for the plugin's top level, i.e. the window title of the dialog.
 #'		Will only be used if \code{dialog} or \code{wizard} are \code{NULL}.
 #' @param clean.name Logical, if \code{TRUE}, all non-alphanumeric characters except the underscore (\code{"_"}) will be removed from \code{name}.
@@ -44,7 +44,7 @@
 #' test.plugin <- rk.XML.plugin("My test", dialog=rk.XML.dialog(test.tabbook))
 #' }
 
-rk.XML.plugin <- function(name, dialog=NULL, wizard=NULL, logic=NULL, snippets=NULL, provides=NULL, help=TRUE, pluginmap=NULL,
+rk.XML.plugin <- function(name, dialog=NULL, wizard=NULL, logic=NULL, snippets=NULL, provides=NULL, help=TRUE, include=NULL,
 	label=NULL, clean.name=TRUE, about=NULL, dependencies=NULL, gen.info=TRUE){
 	if(isTRUE(clean.name)){
 		name.orig <- name
@@ -63,8 +63,10 @@
 		all.children[[length(all.children)+1]] <- rk.XML.help(file=paste0(name, ".rkh"))
 	} else {}
 
-	if(!is.null(pluginmap)){
-		all.children[[length(all.children)+1]] <- rk.XML.include(file=pluginmap)
+	if(!is.null(include)){
+		for (thisInclude in include) {
+			all.children[[length(all.children)+1]] <- rk.XML.include(file=thisInclude)
+		}
 	} else {}
 
 	# check about and dependencies

Modified: trunk/rkward/packages/rkwarddev/R/rk.plugin.component.R
===================================================================
--- trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R	2013-04-04 19:47:50 UTC (rev 4672)
@@ -223,7 +223,6 @@
 		scan=scan,
 		guess.getter=guess.getter,
 		hierarchy=pluginmap[["hierarchy"]],
-		pluginmap=paste0("../", name, ".pluginmap"),
 		create=create[create %in% c("xml", "js", "rkh")],
 		gen.info=gen.info,
 		indent.by=indent.by)

Modified: trunk/rkward/packages/rkwarddev/R/rkwarddev-package.R
===================================================================
--- trunk/rkward/packages/rkwarddev/R/rkwarddev-package.R	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/R/rkwarddev-package.R	2013-04-04 19:47:50 UTC (rev 4672)
@@ -4,7 +4,7 @@
 #' Package: \tab rkwarddev\cr
 #' Type: \tab Package\cr
 #' Version: \tab 0.06-2\cr
-#' Date: \tab 2013-03-13\cr
+#' Date: \tab 2013-04-04\cr
 #' Depends: \tab R (>= 2.9.0),methods,XiMpLe (>= 0.03-18),rkward (>= 0.5.6)\cr
 #' Enhances: \tab rkward\cr
 #' Encoding: \tab UTF-8\cr

Modified: trunk/rkward/packages/rkwarddev/inst/NEWS.Rd
===================================================================
--- trunk/rkward/packages/rkwarddev/inst/NEWS.Rd	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/inst/NEWS.Rd	2013-04-04 19:47:50 UTC (rev 4672)
@@ -1,7 +1,7 @@
 \name{NEWS}
 \title{News for Package 'rkwarddev'}
 \encoding{UTF-8}
-\section{Changes in rkwarddev version 0.06-2 (2013-03-13)}{
+\section{Changes in rkwarddev version 0.06-2 (2013-04-04)}{
   \subsection{changed}{
     \itemize{
       \item the structure of <about> nodes will change in RKWard 0.6.1,
@@ -12,6 +12,9 @@
       \item \code{rk.XML.pluginmap()}, \code{rk.XML.plugin()} and \code{rk.plugin.skeleton()} will now
         move <dependencies> from <about> to a top level child node of plugin maps,
         with a warning
+      \item from \code{rk.plugin.component()} and \code{rk.XML.plugin()}, the \code{"pluginmap"} argument
+        was replaced by the more general \code{"include"}, which can now also process a
+        vector of file names
       \item the object class rk.JS.var gained a new slot \code{"getter"} to set a default JS
         function to query variable values. it defaults to \code{"getValue"} to ensure
         compatibility with earlier releases. consequently, \code{rk.JS.vars()} and
@@ -54,6 +57,7 @@
         \code{rk.JS.scan()} dealt with <frame> nodes, which was also fixed
       \item fixed a duplicate entry in this ChangeLog for version 0.04-6
       \item \code{rk.plugin.skeleton()} now correctly works with more than one author
+      \item pluginmap files are no longer included into plugin XML files automatically
     }
   }
 }

Modified: trunk/rkward/packages/rkwarddev/inst/doc/rkwarddev_vignette.pdf
===================================================================
(Binary files differ)

Modified: trunk/rkward/packages/rkwarddev/man/rk.XML.plugin.Rd
===================================================================
--- trunk/rkward/packages/rkwarddev/man/rk.XML.plugin.Rd	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/man/rk.XML.plugin.Rd	2013-04-04 19:47:50 UTC (rev 4672)
@@ -4,7 +4,7 @@
 \usage{
   rk.XML.plugin(name, dialog = NULL, wizard = NULL,
     logic = NULL, snippets = NULL, provides = NULL,
-    help = TRUE, pluginmap = NULL, label = NULL,
+    help = TRUE, include = NULL, label = NULL,
     clean.name = TRUE, about = NULL, dependencies = NULL,
     gen.info = TRUE)
 }
@@ -45,9 +45,9 @@
   help file named \emph{"<name>.rkh"} will be added to the
   header.}
 
-  \item{pluginmap}{Character string, relative path to the
-  pluginmap file, which will then be included in the head
-  of this document.}
+  \item{include}{Character string or vector, relative
+  path(s) to other file(s), which will then be included in
+  the head of the GUI XML document.}
 
   \item{label}{Character string, a text label for the
   plugin's top level, i.e. the window title of the dialog.

Modified: trunk/rkward/packages/rkwarddev/man/rk.plugin.component.Rd
===================================================================
--- trunk/rkward/packages/rkwarddev/man/rk.plugin.component.Rd	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/man/rk.plugin.component.Rd	2013-04-04 19:47:50 UTC (rev 4672)
@@ -6,7 +6,7 @@
     rkh = list(), provides = c("logic", "dialog"),
     scan = c("var", "saveobj", "settings"),
     guess.getter = FALSE, hierarchy = "test",
-    pluginmap = NULL, create = c("xml", "js", "rkh"),
+    include = NULL, create = c("xml", "js", "rkh"),
     gen.info = TRUE, indent.by = "\t")
 }
 \arguments{
@@ -97,9 +97,9 @@
   place it in a "test" menu. If \code{hierarchy} is a list,
   each entry represents the label of a menu level.}
 
-  \item{pluginmap}{Character string, relative path to the
-  pluginmap file, which will then be included in the head
-  of the GUI XML document.}
+  \item{include}{Character string or vector, relative
+  path(s) to other file(s), which will then be included in
+  the head of the GUI XML document.}
 
   \item{create}{A character vector with one or more of
   these possible entries: \describe{

Modified: trunk/rkward/packages/rkwarddev/man/rkwarddev-package.Rd
===================================================================
--- trunk/rkward/packages/rkwarddev/man/rkwarddev-package.Rd	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/man/rkwarddev-package.Rd	2013-04-04 19:47:50 UTC (rev 4672)
@@ -9,7 +9,7 @@
 \details{
   \tabular{ll}{ Package: \tab rkwarddev\cr Type: \tab
   Package\cr Version: \tab 0.06-2\cr Date: \tab
-  2013-03-13\cr Depends: \tab R (>= 2.9.0),methods,XiMpLe
+  2013-04-04\cr Depends: \tab R (>= 2.9.0),methods,XiMpLe
   (>= 0.03-18),rkward (>= 0.5.6)\cr Enhances: \tab
   rkward\cr Encoding: \tab UTF-8\cr License: \tab GPL (>=
   3)\cr LazyLoad: \tab yes\cr URL: \tab





More information about the rkward-tracker mailing list
--- trunk/rkward/packages/rkwarddev/R/rk.plugin.component.R	2013-04-04 19:45:37 UTC (rev 4671)
+++ trunk/rkward/packages/rkwarddev/R/rk.plugin.component.R	2013-04-04 19:47:50 UTC (rev 4672)
@@ -36,7 +36,7 @@
 #'		Valid single values are \code{"file"}, \code{"edit"}, \code{"view"}, \code{"workspace"}, \code{"run"}, \code{"data"},
 #'		\code{"analysis"}, \code{"plots"}, \code{"distributions"}, \code{"windows"}, \code{"settings"} and \code{"help"},
 #'		anything else will place it in a "test" menu. If \code{hierarchy} is a list, each entry represents the label of a menu level.
 #' @param pluginmap Character string, relative path to the pluginmap file, which will then be included in the head of the GUI XML document.
 #' @param create A character vector with one or more of these possible entries:
 #'		\describe{
 #'			\item{\code{"xml"}}{Create the plugin \code{.xml} XML file skeleton.}
@@ -69,7 +69,7 @@
 
 rk.plugin.component <- function(about, xml=list(), js=list(), rkh=list(),
 	provides=c("logic", "dialog"), scan=c("var", "saveobj", "settings"), guess.getter=FALSE,
-	hierarchy="test", pluginmap=NULL, create=c("xml", "js", "rkh"), gen.info=TRUE, indent.by="\t"){
+	hierarchy="test", include=NULL, create=c("xml", "js", "rkh"), gen.info=TRUE, indent.by="\t"){
 
 	if(inherits(about, "XiMpLe.node")){
 		about.node.name <- slot(about, "name")
@@ -124,7 +124,7 @@
 			logic=xml[["logic"]],
 			snippets=xml[["snippets"]],
 			provides=provides,
-			pluginmap=pluginmap,
+			include=include,
 			about=about.node,
 			gen.info=gen.info)
 		slot(this.component, "xml") <- XML.plugin
@@ -36,7 +36,7 @@
 #'		\code{"analysis"}, \code{"plots"}, \code{"distributions"}, \code{"windows"}, \code{"settings"} and \code{"help"},
 #'		anything else will place it in a "test" menu. If \code{hierarchy} is a list, each entry represents the label of a menu level.
-#' @param pluginmap Character string, relative path to the pluginmap file, which will then be included in the head of the GUI XML document.
+#' @param include Character string or vector, relative path(s) to other file(s), which will then be included in the head of the GUI XML document.
 #' @param create A character vector with one or more of these possible entries:
 #'		\describe{

Modified: trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R
===================================================================